summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--crawl-ref/source/artefact.cc5
1 files changed, 4 insertions, 1 deletions
diff --git a/crawl-ref/source/artefact.cc b/crawl-ref/source/artefact.cc
index f01455ab7e..7426432b3f 100644
--- a/crawl-ref/source/artefact.cc
+++ b/crawl-ref/source/artefact.cc
@@ -152,7 +152,10 @@ static bool _god_fits_artefact(const god_type which_god, const item_def &item,
break;
case GOD_ZIN:
- // Lawful god: no mutagenics.
+ // Lawful god: no chaos, no mutagenics.
+ if (brand == SPWPN_CHAOS)
+ return (false);
+
if (artefact_wpn_property(item, ARTP_MUTAGENIC))
return (false);
break;